function [ modisData ] = modisClientGetQC( modisData, qaBand )
%
% modisClientGetQC: use the modisClient to add QC information to modis data
%
%	modisClientGetQC( modisData, qcBand )
%	returns a data structure that is the same as modisData except
%	that an additional array containing quality control information
%	is appended to the structure. The resulting data structure may
%	then be masked using modisMaskQC
%
%	qaBand must be a string, and the name of a valid Modis band for
%	the same product that is contained in modisData
%	
%	See also: modisClient and modisMaskQC
%	
%       For more information on the MODIS land products:
%       https://lpdaac.usgs.gov/lpdaac/products/modis_products_table/
%
% Tristan Quaife, Meteorology, University of Reading. (16/07/2012)
% t.l.quaife@reading.ac.uk
  
  %check the number of arguments passed is OK =========
  if nargin~=2	
		error( 'modisClientGetQC: expects exactly two arguments' ) ;
  end

  p=modisData.product;
  t=modisData.latitude;
  n=modisData.longitude;
  s=modisData.userStartDate;
  e=modisData.userEndDate;
  a=modisData.userkmAboveBelow;
  l=modisData.userkmLeftRight;
  
  q=modisClient( p, qaBand, t, n, s, e, a, l );
  
  modisData.QC=q.data;
  modisData.gotQC=true;

  
end

