function modisData = modisMaskQC( modisData, QCOK, fillValue )
%
% modisMaskQC: mask modis data based on relevant QC data
%
%	modisMaskQC( modisData, QCOK )
%	returns a data structure that is the same as modisData except
%	that data that does not pass QC is replaced with a fill value
%	(which may be optionally specified as a 3rd argument - otherwise 
%	a default value of NaN is used).
%
%	The modisData structure must contain QC information: the
%	recommended way of adding this is to use modisClientGetQC.
%   
%	The list QCOK must contain the list of QC integers that the 
%	user wants to be passed. 
%
%	See also: modisClient and modisClientGetQC
%	
%       For more information on the MODIS land products:
%       https://lpdaac.usgs.gov/lpdaac/products/modis_products_table/
%
% Tristan Quaife, Meteorology, University of Reading. (16/07/2012)
% t.l.quaife@reading.ac.uk

	%check the number of arguments passed is OK =========
	if nargin<2	
		error( 'modisMaskQC: insufficient arguments to function' ) ;
	end

	%set default fill value =============================
	if nargin==2	
		fillValue=NaN ;
    end


    %check structure contains QC data
    if modisData.gotQC == false
        error( 'modisMaskQC: data structure does not contain QC information' ) ;
    end
    
    
	%filter out values: ==================================
	for i=1:length( modisData.data(:) )
		if( sum(  modisData.QC(i) == QCOK ) == 0 )
			modisData.data(i)=fillValue ;
		end
	end
	
	

end


